@@ -3,6 +3,15 @@ __DATA__
 
 #line 5 "(PApp/Apache.pm)"
 
+##########################################################################
+## All portions of this code are copyright (c) 2003,2004 nethype GmbH   ##
+##########################################################################
+## Using, reading, modifying or copying this code requires a LICENSE    ##
+## from nethype GmbH, Franz-Werfel-Str. 11, 74078 Heilbronn,            ##
+## Germany. If you happen to have questions, feel free to contact us at ##
+## license@nethype.de.                                                  ##
+##########################################################################
+
 =head1 NAME
 
 PApp::Apache - multi-page-state-preserving web applications
@@ -53,7 +62,7 @@ use PApp::Package;
 BEGIN {
    @ISA = PApp::Base::;
    unshift @PApp::ISA, __PACKAGE__;
-   $VERSION = 0.22;
+   $VERSION = 0.95;
 }
 
 *PApp::OK = \&Apache::Constants::OK;
@@ -92,10 +101,6 @@ sub configure {
    $self->SUPER::configure(@_);
 }
 
-sub mount {
-   my $self = shift;
-}
-
 sub mount {
    my $self = shift;
    my $papp = shift;
